@@ -13,5 +13,7 @@ VCS = {
     "commit_message": (
         "Version updated from {{ current_version }}" " to {{ new_version }}"
     ),
-    "target_branch": "main",
+    "options": {
+        "target_branch": "main",
+    },
 }
