@@ -6,7 +6,7 @@ import sys
 
 import yaml
 
-from mau import __version__, Mau
+from mau import __version__, Mau, ConfigurationError, ParserError
 
 __author__ = "Leonardo Giordani"
 __copyright__ = "Leonardo Giordani"
@@ -14,6 +14,14 @@ __license__ = "mit"
 
 _logger = logging.getLogger(__name__)
 
+# This is a convenience dictionary that collects the output formats
+# that Mau supports and some matadata
+FORMATS = {
+    "html": {"extension": ".html"},
+    "asciidoctor": {"extension": ".adoc"},
+    "markua": {"extension": ".md"},
+}
+
 
 def parse_args(args):
     parser = argparse.ArgumentParser()
@@ -46,8 +54,7 @@ def parse_args(args):
         "--format",
         action="store",
         required=False,
-        default="html",
-        choices=["html", "asciidoctor", "markua"],
+        choices=FORMATS.keys(),
         help="Output format",
     )
 
@@ -82,36 +89,61 @@ def setup_logging(loglevel):
 
 
 def main(args):
+    # Get arguments and logging set up
     args = parse_args(args)
     setup_logging(args.loglevel)
 
+    # Read the input file
     with open(args.input_file, "r") as f:
         text = f.read()
 
+    # Load the YAML configuration file into a dictionary
     config = {}
     if args.config_file:
         with open(args.config_file, "r") as f:
             config = yaml.load(f, Loader=yaml.FullLoader)
 
-    templates_directory = f'{config["theme"]}/templates' if "theme" in config else None
+    # The directory that contains custom templates.
+    templates_directory = config.get("templates_directory", None)
 
+    # If a target format is specified on the command line
+    # override the one already set in the config file
+    # or set it if it isn't.
+    if args.format is not None:
+        config["target_format"] = args.format
+
+    # This extracts the custom templates defined
+    # in the config file
+    custom_templates = config.get("custom_templates", None)
+
+    # The Mau object configured with what we figured out above.
     mau = Mau(
         config,
-        target_format=args.format,
+        None,
+        custom_templates=custom_templates,
         templates_directory=templates_directory,
         full_document=True,
     )
-    output = mau.process(text)
 
-    if args.format == "html":
-        output_extension = ".html"
-    elif args.format == "asciidoctor":
-        output_extension = ".adoc"
-    elif args.format == "markua":
-        output_extension = ".md"
+    try:
+        # Process the input text.
+        output = mau.process(text)
+    except ConfigurationError as e:
+        print(f"Configuration error: {e}")
+        sys.exit(1)
+    except ParserError as e:
+        print(str(e))
+        print()
+        print(f"Line {e.context['line']}, column {e.context['column']}")
+        for i in e.context["text"]:
+            print(i)
+        sys.exit(1)
 
+    # Find out the name of the output file
+    output_extension = FORMATS[config["target_format"]]["extension"]
     output_file = args.output_file or args.input_file.replace(".mau", output_extension)
 
+    # Write the output
     with open(output_file, "w") as f:
         text = f.write(output)
 
