@@ -9,6 +9,48 @@ init_parser = init_parser_factory(TextParser)
 _test = parser_test_factory(TextParser)
 
 
+def test_collect_macro_arguments_single_argument():
+    source = "(value1)"
+
+    p = init_parser(source)
+    assert p._collect_macro_args() == "value1"
+
+
+def test_collect_macro_arguments_multiple_arguments():
+    source = "(value1,value2)"
+
+    p = init_parser(source)
+    assert p._collect_macro_args() == "value1,value2"
+
+
+def test_collect_macro_arguments_single_argument_with_quotes():
+    source = '("value1")'
+
+    p = init_parser(source)
+    assert p._collect_macro_args() == '"value1"'
+
+
+def test_collect_macro_arguments_single_argument_with_quotes_and_parenthesis():
+    source = '("value1()")'
+
+    p = init_parser(source)
+    assert p._collect_macro_args() == '"value1()"'
+
+
+def test_collect_macro_arguments_single_argument_with_parenthesis():
+    source = "(value1())"
+
+    p = init_parser(source)
+    assert p._collect_macro_args() == "value1("
+
+
+def test_collect_macro_arguments_multiple_argument_with_quotes_and_parenthesis():
+    source = '("value1()",value2,value3)'
+
+    p = init_parser(source)
+    assert p._collect_macro_args() == '"value1()",value2,value3'
+
+
 def test_macro():
     source = "[macroname](value1,value2)"
 
@@ -18,7 +60,8 @@ def test_macro():
             "content": [
                 {
                     "type": "macro",
-                    "value": "macroname",
+                    "name": "macroname",
+                    "value": "value1",
                     "args": ["value1", "value2"],
                     "kwargs": {},
                 }
@@ -38,7 +81,8 @@ def test_macro_arguments_with_quotes():
             "content": [
                 {
                     "type": "macro",
-                    "value": "macroname",
+                    "name": "macroname",
+                    "value": "value1,value2",
                     "args": ["value1,value2"],
                     "kwargs": {},
                 }
@@ -49,6 +93,27 @@ def test_macro_arguments_with_quotes():
     _test(source, expected)
 
 
+def test_macro_named_arguments():
+    source = "[macroname](name,arg1=value1)"
+
+    expected = [
+        {
+            "type": "sentence",
+            "content": [
+                {
+                    "type": "macro",
+                    "name": "macroname",
+                    "value": "name",
+                    "args": ["name"],
+                    "kwargs": {"arg1": "value1"},
+                }
+            ],
+        }
+    ]
+
+    _test(source, expected)
+
+
 def test_macro_link():
     source = '[link](https://somedomain.org/the/path, "link text")'
 
@@ -107,7 +172,7 @@ def test_macro_link_with_escaped_quotes():
 
 
 def test_macro_link_with_escaped_round_braces():
-    source = '[link](https://somedomain.org/the/path,"link (text\)")'
+    source = '[link](https://somedomain.org/the/path,"link (text\\)")'
 
     expected = [
         {
@@ -126,7 +191,26 @@ def test_macro_link_with_escaped_round_braces():
 
 
 def test_macro_link_with_escaped_round_braces_in_the_url():
-    source = '[link](https://somedomain.org/the/path_(note\),"link")'
+    source = '[link](https://somedomain.org/the/path_(note\\),"link")'
+
+    expected = [
+        {
+            "type": "sentence",
+            "content": [
+                {
+                    "type": "link",
+                    "target": "https://somedomain.org/the/path_(note)",
+                    "text": "link",
+                }
+            ],
+        }
+    ]
+
+    _test(source, expected)
+
+
+def test_macro_link_with_quotes_and_round_braces_in_the_url():
+    source = '[link]("https://somedomain.org/the/path_(note)","link")'
 
     expected = [
         {
@@ -184,6 +268,27 @@ def test_automatic_link():
     _test(source, expected)
 
 
+def test_automatic_link_ending_with_period():
+    source = "The link is https://somedomain.org/the/path."
+
+    expected = [
+        {
+            "type": "sentence",
+            "content": [
+                {"type": "text", "value": "The link is "},
+                {
+                    "type": "link",
+                    "target": "https://somedomain.org/the/path",
+                    "text": "https://somedomain.org/the/path",
+                },
+                {"type": "text", "value": "."},
+            ],
+        }
+    ]
+
+    _test(source, expected)
+
+
 def test_http_mentions():
     source = "Dangerous words: http and https"
 
@@ -314,7 +419,7 @@ def test_macro_footnote(footnote_anchors_mock):
 
     p = _test(source, expected)
 
-    assert listasdict(p.footnotes) == [
+    assert listasdict(p.footnote_defs) == [
         {
             "type": "footnote_def",
             "number": 1,
@@ -441,7 +546,7 @@ def test_parse_macro_footnote_with_other_text_around(footnote_anchors_mock):
 
     p = _test(source, expected)
 
-    assert listasdict(p.footnotes) == [
+    assert listasdict(p.footnote_defs) == [
         {
             "type": "footnote_def",
             "number": 1,
@@ -460,10 +565,10 @@ def test_parse_macro_footnote_with_other_text_around(footnote_anchors_mock):
 
 
 @patch("mau.parsers.text_parser.footnote_anchors")
-def test_parse_macro_footnote_includes_quotes(footnote_anchors_mock):
+def test_parse_macro_footnote_includes_round_brakets(footnote_anchors_mock):
     footnote_anchors_mock.return_value = ("refXYZ", "defXYZ")
 
-    source = 'text[footnote]("Some text") other text'
+    source = r'text[footnote]("Some code()") other text'
 
     expected = [
         {
@@ -479,7 +584,7 @@ def test_parse_macro_footnote_includes_quotes(footnote_anchors_mock):
                         {
                             "type": "sentence",
                             "content": [
-                                {"type": "text", "value": '"Some text"'},
+                                {"type": "text", "value": "Some code()"},
                             ],
                         }
                     ],
@@ -491,7 +596,7 @@ def test_parse_macro_footnote_includes_quotes(footnote_anchors_mock):
 
     p = _test(source, expected)
 
-    assert listasdict(p.footnotes) == [
+    assert listasdict(p.footnote_defs) == [
         {
             "type": "footnote_def",
             "number": 1,
@@ -501,7 +606,7 @@ def test_parse_macro_footnote_includes_quotes(footnote_anchors_mock):
                 {
                     "type": "sentence",
                     "content": [
-                        {"type": "text", "value": '"Some text"'},
+                        {"type": "text", "value": "Some code()"},
                     ],
                 }
             ],
@@ -510,10 +615,14 @@ def test_parse_macro_footnote_includes_quotes(footnote_anchors_mock):
 
 
 @patch("mau.parsers.text_parser.footnote_anchors")
-def test_parse_macro_footnote_includes_round_brakets(footnote_anchors_mock):
+def test_parse_macro_footnote_commas_mau_v1(
+    footnote_anchors_mock,
+):
     footnote_anchors_mock.return_value = ("refXYZ", "defXYZ")
 
-    source = r'text[footnote]("Some code(\)") other text'
+    source = r"text[footnote](Some text, that should not, be split) other text"
+
+    _test = parser_test_factory(TextParser, v1_backward_compatibility=True)
 
     expected = [
         {
@@ -529,7 +638,10 @@ def test_parse_macro_footnote_includes_round_brakets(footnote_anchors_mock):
                         {
                             "type": "sentence",
                             "content": [
-                                {"type": "text", "value": '"Some code()"'},
+                                {
+                                    "type": "text",
+                                    "value": "Some text, that should not, be split",
+                                },
                             ],
                         }
                     ],
@@ -541,7 +653,7 @@ def test_parse_macro_footnote_includes_round_brakets(footnote_anchors_mock):
 
     p = _test(source, expected)
 
-    assert listasdict(p.footnotes) == [
+    assert listasdict(p.footnote_defs) == [
         {
             "type": "footnote_def",
             "number": 1,
@@ -551,7 +663,70 @@ def test_parse_macro_footnote_includes_round_brakets(footnote_anchors_mock):
                 {
                     "type": "sentence",
                     "content": [
-                        {"type": "text", "value": '"Some code()"'},
+                        {
+                            "type": "text",
+                            "value": "Some text, that should not, be split",
+                        },
+                    ],
+                }
+            ],
+        }
+    ]
+
+
+@patch("mau.parsers.text_parser.footnote_anchors")
+def test_parse_macro_footnote_commas_mau_v2(
+    footnote_anchors_mock,
+):
+    footnote_anchors_mock.return_value = ("refXYZ", "defXYZ")
+
+    source = r'text[footnote]("Some text, that should not, be split") other text'
+
+    _test = parser_test_factory(TextParser)
+
+    expected = [
+        {
+            "type": "sentence",
+            "content": [
+                {"type": "text", "value": "text"},
+                {
+                    "type": "footnote_ref",
+                    "number": 1,
+                    "refanchor": "refXYZ",
+                    "defanchor": "defXYZ",
+                    "content": [
+                        {
+                            "type": "sentence",
+                            "content": [
+                                {
+                                    "type": "text",
+                                    "value": "Some text, that should not, be split",
+                                },
+                            ],
+                        }
+                    ],
+                },
+                {"type": "text", "value": " other text"},
+            ],
+        }
+    ]
+
+    p = _test(source, expected)
+
+    assert listasdict(p.footnote_defs) == [
+        {
+            "type": "footnote_def",
+            "number": 1,
+            "refanchor": "refXYZ",
+            "defanchor": "defXYZ",
+            "content": [
+                {
+                    "type": "sentence",
+                    "content": [
+                        {
+                            "type": "text",
+                            "value": "Some text, that should not, be split",
+                        },
                     ],
                 }
             ],
@@ -576,3 +751,85 @@ def test_parse_macro_mailto():
     ]
 
     _test(source, expected)
+
+
+def test_single_class():
+    source = 'Some text [class]("text with that class", classname)'
+
+    expected = [
+        {
+            "type": "sentence",
+            "content": [
+                {"type": "text", "value": "Some text "},
+                {
+                    "type": "class",
+                    "classes": ["classname"],
+                    "content": {
+                        "type": "sentence",
+                        "content": [{"type": "text", "value": "text with that class"}],
+                    },
+                },
+            ],
+        }
+    ]
+
+    _test(source, expected)
+
+
+def test_multiple_classes():
+    source = 'Some text [class]("text with that class", "classname1,classname2")'
+
+    expected = [
+        {
+            "type": "sentence",
+            "content": [
+                {"type": "text", "value": "Some text "},
+                {
+                    "type": "class",
+                    "classes": ["classname1", "classname2"],
+                    "content": {
+                        "type": "sentence",
+                        "content": [{"type": "text", "value": "text with that class"}],
+                    },
+                },
+            ],
+        }
+    ]
+
+    _test(source, expected)
+
+
+def test_parse_class_with_rich_text():
+    source = '[class]("Some text with `verbatim words` and _styled ones_", classname)'
+
+    expected = [
+        {
+            "type": "sentence",
+            "content": [
+                {
+                    "type": "class",
+                    "classes": ["classname"],
+                    "content": {
+                        "type": "sentence",
+                        "content": [
+                            {"type": "text", "value": "Some text with "},
+                            {"type": "verbatim", "value": "verbatim words"},
+                            {"type": "text", "value": " and "},
+                            {
+                                "type": "style",
+                                "value": "underscore",
+                                "content": {
+                                    "type": "sentence",
+                                    "content": [
+                                        {"type": "text", "value": "styled ones"}
+                                    ],
+                                },
+                            },
+                        ],
+                    },
+                }
+            ],
+        }
+    ]
+
+    _test(source, expected)
